AISCOT: Display Ships in TAK - AIS to TAK Gateway 
*************************************************

.. image:: https://raw.githubusercontent.com/ampledata/aiscot/main/docs/screenshot_1676076870_2962.png
   :alt: Screenshot of ships in ATAK.
   :target: https://raw.githubusercontent.com/ampledata/aiscot/main/docs/screenshot_1676076870_2962.png

Description
===========

AISCOT 
The Automatic Identification System to Cursor on Target gateway (AISCOT) transforms 
automatic identification system (AIS) to Cursor on Target (CoT) for use with TAK 
products such as ATAK, WinTAK & iTAK. Vessels sending AIS either 
over the air (RF), through a local networks (NMEA), or through internet aggregators 
(AISHUB), will be displayed in TAK with appropriate icons, attitude, type, track, 
bearing, speed, callsign and more.

For more information the TAK Product suite, see: https://ww.tak.gov

AISCOT was original developed to support an open ocean boat race in the Northern 
Pacific Ocean, as described in this article: http://ampledata.org/boat_race_support.html


License & Copyright
===================

Copyright Sensors & Signals LLC https://www.snstac.com

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at [http://www.apache.org/licenses/LICENSE-2.0](http://www.apache.org/licenses/LICENSE-2.0)

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

* pyAISm.py is licensed under the MIT License. See aiscot/pyAISm.py for details.
